@@ -117,10 +117,13 @@ class xdict(dict):
     def has_key(self, k):
         if isinstance(k, (str, unicode)) and '.' in k:
             k, rest = k.split('.', 1)
-            child = self[k]
-            if not isinstance(child, dict):
+            if dict.has_key(self, k):
+                child = self[k]
+                if not isinstance(child, dict):
+                    return False
+                return child.has_key(rest)
+            else:
                 return False
-            return child.has_key(rest)
             
         return dict.has_key(self, k)
     
